@@ -1,30 +1,5 @@
 package DBIx::Admin::BackupRestore;
 
-# Documentation:
-#	POD-style documentation is at the end. Extract it with pod2html.*.
-#
-# Reference:
-#	Object Oriented Perl
-#	Damian Conway
-#	Manning
-#	1-884777-79-1
-#	P 114
-#
-# Note:
-#	o Tab = 4 spaces || die.
-#
-# Author:
-#	Ron Savage <ron@savage.net.au>
-#	Home page: http://savage.net.au/index.html
-#
-# Licence:
-#	Australian copyright (c) 2003 Ron Savage.
-#
-#	All Programs of mine are 'OSI Certified Open Source Software';
-#	you can redistribute them and/or modify them under the terms of
-#	The Artistic License, a copy of which is available at:
-#	http://www.opensource.org/licenses/index.html
-
 use strict;
 use warnings;
 
@@ -32,29 +7,7 @@ use Carp;
 use File::Spec;
 use XML::Records;
 
-require 5.005_62;
-
-require Exporter;
-
-our @ISA = qw(Exporter);
-
-# Items to export into callers namespace by default. Note: do not export
-# names by default without a very good reason. Use EXPORT_OK instead.
-# Do not simply export all your public functions/methods/constants.
-
-# This allows declaration	use DBIx::Admin::BackupRestore ':all';
-# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
-# will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw(
-
-) ] );
-
-our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-
-our @EXPORT = qw(
-
-);
-our $VERSION = '1.17';
+our $VERSION = '1.18';
 
 my(%_decode_xml) =
 (
@@ -1095,7 +1048,7 @@ Hence the error about 'duplicate key'.
 
 =back
 
-=head1 Related Modules
+=head1 See Also
 
 On CPAN I can see 4 modules which obviously offer similar features - there may be
 others.
@@ -1118,12 +1071,22 @@ Sergeant for that module.
 I have effectively extended his module to automatically handle all tables, and to
 handle importing too.
 
+=head1 Repository
+
+L<https://github.com/ronsavage/DBIx-Admin-BackupRestore.git>
+
+=head1 SUPPORT
+
+Bugs should be reported via the CPAN bug tracker at
+
+L<https://github.com/ronsavage/DBIx-Admin-BackupRestore/issues>
+
 =head1 Author
 
 C<DBIx::Admin::BackupRestore> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>>
 in 2004.
 
-Home page: http://savage.net.au/index.html
+L<http://savage.net.au/>
 
 =head1 Copyright
 
